@@ -1,4 +1,3 @@
-import socketserver
 import socket
 import time
 import threading
@@ -969,59 +968,25 @@ import Fiume.metainfo_decoder as md
 import bencodepy
 import argparse
 
-# TODO move to utils
-def int_to_loglevel(n):
-    if n == 0:
-        return logging.WARNING
-    if n == 1:
-        return logging.INFO
+# options = {
+#     "torrent_path": pathlib.Path("/home/groucho/Un gioco di specchi.mp4.torrent"),
+#     "output_file":  pathlib.Path("/home/groucho/torrent/downloads/film.mp4"),
+#     "delay": 0,
+#     "debug": False,
+#     "debug-level": logging.WARNING
+# }
 
-    return logging.ERROR
-    
-if __name__ == "__main__":
-    parser = argparse.ArgumentParser()
-    parser.add_argument("torrent_path",
-                        type=pathlib.Path,
-                        help="path to .torrent file")
-    parser.add_argument("download_path",
-                        type=pathlib.Path,
-                        help="where to download the file")
-    parser.add_argument("-v", "--verbosity",
-                        # choices=[0,1,2], #warn,info,debug
-                        action="count",
-                        default=0,
-                        help="debug level")
-    parser.add_argument("--delay",
-                        type=float,
-                        default=0,
-                        help="delay for every sent message (only debug)")
+# with open(options["torrent_path"], "rb") as f:
+#     metainfo = md.MetaInfo(
+#         bencodepy.decode(f.read()) | options
+#     )
 
-    options = vars(parser.parse_args())
-    options["verbosity"] = int_to_loglevel(a["verbosity"])
-    options["debug"] = False
-    
-if __name__ != "__main__":
-    options = {
-        "torrent_path": pathlib.Path("/home/groucho/Un gioco di specchi.mp4.torrent"),
-        "output_file":  pathlib.Path("/home/groucho/torrent/downloads/film.mp4"),
-        "delay": 0,
-        "debug": False,
-        "debug-level": logging.WARNING
-    }
+# tm = md.TrackerManager(metainfo, options)
 
-###########
+# t = ThreadedServer(
+#     50146,
+#     metainfo, tm,
+#     **options
+# )
 
-with open(options["torrent_path"], "rb") as f:
-    metainfo = md.MetaInfo(
-        bencodepy.decode(f.read()) | options
-    )
-
-tm = md.TrackerManager(metainfo, options)
-
-t = ThreadedServer(
-    50146,
-    metainfo, tm,
-    **options
-)
-
-t.main()
+# t.main()
